#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Setup script for climalab package.
This file defers to pyproject.toml for configuration.
"""

from setuptools import setup

# Defer to pyproject.toml for all configuration
setup()
